@@ -112,6 +112,7 @@ static void
 text_size (HTMLGdkPainter *painter, PangoFontDescription *desc, const gchar *text, gint bytes,
 	   HTMLTextPangoInfo *pi, PangoAttrList *attrs, GList *glyphs, gint start_byte_offset, gint *width, gint *asc, gint *dsc)
 {
+	PangoFontMetrics *pfm;
 	gboolean temp_pi = FALSE;
 	if (!pi) {
 		pi = html_painter_text_itemize_and_prepare_glyphs (HTML_PAINTER (painter), desc, text, bytes, &glyphs, attrs);
@@ -132,10 +133,16 @@ text_size (HTMLGdkPainter *painter, PangoFontDescription *desc, const gchar *tex
 			str = (PangoGlyphString *) gl->data;
 			gl = gl->next;
 			ii = GPOINTER_TO_INT (gl->data);
-			pango_glyph_string_extents (str, pi->entries [ii].item->analysis.font, NULL, &log_rect);
+			item = pi->entries [ii].item;
+			pango_glyph_string_extents (str, item->analysis.font, NULL, &log_rect);
 			*width += PANGO_PIXELS (log_rect.width);
-			*asc = MAX (*asc, PANGO_PIXELS (PANGO_ASCENT (log_rect)));
-			*dsc = MAX (*dsc, PANGO_PIXELS (PANGO_DESCENT (log_rect)));
+
+			pfm = pango_font_get_metrics (item->analysis.font, item->analysis.language);
+			if (asc)
+				*asc = MAX (*asc, PANGO_PIXELS (pango_font_metrics_get_ascent (pfm)));
+			if (dsc)
+				*dsc = MAX (*dsc, PANGO_PIXELS (pango_font_metrics_get_descent (pfm)));
+			pango_font_metrics_unref (pfm);
 
 			c_text = g_utf8_offset_to_pointer (c_text, str->num_glyphs);
 			if (*text == '\t')
@@ -159,18 +166,15 @@ alloc_font (HTMLPainter *painter, gchar *face, gdouble size, gboolean points, Gt
 	gint space_width, space_asc, space_dsc;
 
 	if (face) {
-		gchar *str;
-
-		str = g_strdup_printf ("%s %d", face, (gint) size);
-		desc = pango_font_description_from_string (str);
-		g_free (str);
+		desc = pango_font_description_from_string (face);
+		pango_font_description_set_size (desc, (gint) size);
 	}
 
 	if (!desc || !pango_font_description_get_family (desc)) {
 		if (desc)
 			pango_font_description_free (desc);
 
-		desc = pango_font_description_copy (painter->widget->style->font_desc);
+		desc = pango_font_description_copy (gtk_widget_get_style (painter->widget)->font_desc);
 	}
 
 	pango_font_description_set_size (desc, size);
@@ -178,8 +182,10 @@ alloc_font (HTMLPainter *painter, gchar *face, gdouble size, gboolean points, Gt
 	pango_font_description_set_weight (desc, style & GTK_HTML_FONT_STYLE_BOLD ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL);
 
 	text_size (HTML_GDK_PAINTER (painter), desc, " ", 1, NULL, NULL, NULL, 0, &space_width, &space_asc, &space_dsc);
+
 	return html_font_new (desc,
-			      space_width, space_asc, space_dsc,
+			      space_width,
+			      space_asc, space_dsc,
 			      text_width (HTML_GDK_PAINTER (painter), desc, "\xc2\xa0", 2),
 			      text_width (HTML_GDK_PAINTER (painter), desc, "\t", 1),
 			      text_width (HTML_GDK_PAINTER (painter), desc, HTML_BLOCK_INDENT, strlen (HTML_BLOCK_INDENT)),
@@ -1186,6 +1192,19 @@ html_gdk_painter_init (GObject *object)
 	init_color (& gdk_painter->light, 0, 0, 0);
 }
 
+static void
+html_gdk_painter_real_set_widget (HTMLPainter *painter, GtkWidget *widget)
+{
+	HTMLGdkPainter *gdk_painter = HTML_GDK_PAINTER (painter);
+
+	parent_class->set_widget (painter, widget);
+
+	if (gdk_painter->pc)
+		g_object_unref (gdk_painter->pc);
+	gdk_painter->pc = gtk_widget_get_pango_context (widget);
+	g_object_ref (gdk_painter->pc);
+}
+
 static void
 html_gdk_painter_class_init (GObjectClass *object_class)
 {
@@ -1196,6 +1215,7 @@ html_gdk_painter_class_init (GObjectClass *object_class)
 	object_class->finalize = finalize;
 	parent_class = g_type_class_ref (HTML_TYPE_PAINTER);
 
+	painter_class->set_widget = html_gdk_painter_real_set_widget;
 	painter_class->begin = begin;
 	painter_class->end = end;
 	painter_class->alloc_font = alloc_font;
@@ -1259,8 +1279,6 @@ html_gdk_painter_new (GtkWidget *widget, gboolean double_buffer)
 
 	new->double_buffer = double_buffer;
 	html_painter_set_widget (HTML_PAINTER (new), widget);
-	new->pc = gtk_widget_get_pango_context (widget);
-	g_object_ref (new->pc);
 
 	return HTML_PAINTER (new);
 }
@@ -1271,7 +1289,7 @@ html_gdk_painter_realize (HTMLGdkPainter *gdk_painter,
 {
 	g_return_if_fail (gdk_painter != NULL);
 	g_return_if_fail (window != NULL);
-	
+
 	gdk_painter->gc = gdk_gc_new (window);
 	gdk_painter->window = window;
 
