@@ -30,7 +30,7 @@
 */
 
 #include <config.h>
-#include <gal/unicode/gunicode.h>
+
 #include "htmlsearch.h"
 #include "htmlobject.h"
 #include "htmlentity.h"
@@ -39,8 +39,8 @@
 static void
 set_text (HTMLSearch *s, const gchar *text)
 {
-	s->text           = g_strdup (text);
-	s->text_len       = g_utf8_strlen (text, -1);
+	s->text = g_strdup (text);
+	s->text_bytes = strlen (text);
 }
 
 HTMLSearch *
@@ -91,7 +91,7 @@ html_search_new (HTMLEngine *e, const gchar *text, gboolean case_sensitive, gboo
 		ns->reb = g_new0 (regex_t, 1);
 
 		ns->reb->translate = ns->trans;
-		rv = re_compile_pattern (ns->text, ns->text_len, ns->reb);
+		rv = re_compile_pattern (ns->text, ns->text_bytes, ns->reb);
 		if (rv) {
 			g_warning (rv);
 		}
@@ -103,7 +103,7 @@ html_search_new (HTMLEngine *e, const gchar *text, gboolean case_sensitive, gboo
 		rv_int = regcomp (ns->reb, ns->text, (case_sensitive) ? 0 : REG_ICASE);
 		if (rv_int) {
 			char buf[1024];
-			if (regerror(rv_int, ns->reb, &buf, sizeof(buf))) {
+			if (regerror(rv_int, ns->reb, buf, sizeof(buf))) {
 				g_warning (buf);
 			} else {
 				g_warning ("regcomp failed, error code %d", rv_int);
